# GPUC-CLI

Le projet GPUC-CLI est un outil en ligne de commande développé en Python pour gérer les fichiers d'autorisation liés aux employés et aux structures.

<!-- TOC -->
* [GPUC-CLI](#gpuc-cli)
  * [Outils](#outils)
  * [Pré-requis](#pré-requis)
  * [Commandes disponibles](#commandes-disponibles)
    * [Génération du fichier d'autorisation des employés](#génération-du-fichier-dautorisation-des-employés)
    * [Génération des fichiers structures](#génération-des-fichiers-structures)
<!-- TOC -->

## Outils

- 🐍 Python 3.10+
- 🧰 [argparse](https://docs.python.org/3/library/argparse.html) pour la gestion des arguments CLI.
- 🚀 [sops](https://github.com/mozilla/sops) pour le chiffrement des fichiers.
- 🔒 [age](https://github.com/FiloSottile/age) pour le backend de chiffrement.
- 🏎 [uv](https://docs.astral.sh/uv/) pour la gestion des dépendances et du projet.

## Pré-requis

Avant d'utiliser GPUC CLI, assurez-vous que les outils suivants sont installés :

1. **Sops** : Utilisé pour le chiffrement des fichiers de paramétrage.
   - Installation : [https://github.com/mozilla/sops](https://github.com/mozilla/sops)

2. **Age** : Backend de chiffrement utilisé par Sops.
   - Installation : [https://github.com/FiloSottile/age](https://github.com/FiloSottile/age)

3. **uv** : Gestionnaire de projet et de dépendances.
   - Installation : [https://docs.astral.sh/uv/](https://docs.astral.sh/uv/)

## Commandes disponibles

### Génération du fichier d'autorisation des employés

La commande `people` permet de gérer les fichiers d'autorisation liés aux employés et/ou aux étudiants.

#### Syntaxe

```bash
uv run gpuc people [--verbose] generate [--population <mode>] [--sftp]
```

#### Arguments

- `generate` : Action pour générer les fichiers d'autorisation.
- `--population` : Mode de génération des fichiers :
  - `PERSONNEL_ONLY` : Génère uniquement les données des employés.
  - `STUDENT_ONLY` : Génère uniquement les données des étudiants.
  - `ALL` : Génère les données des employés et des étudiants.
- `--sftp` : Envoie le fichier généré via SFTP sur le serveur.
- `--verbose` : Active les logs détaillés dans la console.

#### Exemple

```bash
uv run gpuc people --verbose generate --population ALL --sftp
```

### Génération des fichiers structures

La commande `structure` permet de gérer les fichiers liés aux structures.

#### Syntaxe

```bash
uv run gpuc structure [--verbose] generate [--sftp]
```

#### Arguments

- `generate` : Action pour générer les fichiers liés aux structures.
- `--sftp` : Envoie les fichiers générés via SFTP.
- `--verbose` : Active les logs détaillés dans la console.

#### Exemple

```bash
uv run gpuc structure --verbose generate --sftp
```

> 💡 **TIP**
> - Utilisez l'option `--help` pour afficher l'aide détaillée des commandes :
> ```bash
> uv run gpuc --help
> ```
> - Utilisez `uvx` pour exécuter les commandes sans avoir besoin de cloner le dépôt ou d'installer le package :
> ```bash
> uvx --env-file ~/.env/gpuc.env --extra-index-url https://git.univ-reunion.fr/api/packages/sda-python/pypi/simple/ --from gpuc gpuc people generate --population all --sftp
> ```