from dataclasses import dataclass


@dataclass
class People:
    """Classe représentant une personne dans l'annuaire LDAP"""

    cn: str
    sn: list[str]
    runUnivNom: list[str]
    runUnivPrenom: list[str]
    supannAliaslogin: str
    mail: str
    runUnivSihamId: str
    runUnivAuthorization: list[str] | None
    supannEntiteAffectationPrincipale: str

    def __post_init__(self):
        self.sn = [self.sn] if isinstance(self.sn, str) else self.sn
        self.runUnivNom = (
            [self.runUnivNom] if isinstance(self.runUnivNom, str) else self.runUnivNom
        )
        self.runUnivPrenom = (
            [self.runUnivPrenom]
            if isinstance(self.runUnivPrenom, str)
            else self.runUnivPrenom
        )
        self.runUnivAuthorization = (
            [self.runUnivAuthorization]
            if isinstance(self.runUnivAuthorization, str)
            else self.runUnivAuthorization
        )

    def to_gpuc(self) -> dict[str, str]:
        """Convertit l'objet en dictionnaire pour l'utilisation avec GPuc

        Returns:
            Dictionnaire pour la création des données GPUC
        """

        return {
            "uid": self.supannAliaslogin,
            "nom": self.runUnivNom,
            "prenom": self.runUnivPrenom,
            "mail": self.mail,
            "affectation": self.supannEntiteAffectationPrincipale,
        }
